#include <iostream>
#include <vector>
#include <climits>

using namespace std;

struct Edge {
    int to, weight;
};

void dijkstra(int N, const vector<vector<Edge>>& graph, vector<int>& dist) {
    vector<bool> visited(N + 1, false);

    dist[1] = 0;

    for (int i = 1; i <= N; ++i) {
        int u = -1;
        for (int v = 1; v <= N; ++v) {
            if (!visited[v] && (u == -1 || dist[v] < dist[u])) {
                u = v;
            }
        }

        if (dist[u] == INT_MAX) break;

        visited[u] = true;
        for (const Edge& e : graph[u]) {
            int v = e.to;
            int weight = e.weight;
            if (dist[u] + weight < dist[v]) {
                dist[v] = dist[u] + weight;
            }
        }
    }
}

int main() {
    int N, M;
    cin >> N >> M;

    vector<vector<Edge>> graph(N + 1);

    for (int i = 0; i < M; ++i) {
        int u, l, r;
        cin >> u >> l >> r;

        for (int v = l; v <= r; ++v) {
            int weight = v - l + 1;
            graph[u].push_back({v, weight});
        }
    }

    vector<int> dist(N + 1, INT_MAX);

    dijkstra(N, graph, dist);

    for (int i = 1; i <= N; ++i) {
        if (dist[i] == INT_MAX) {
            cout << -1 << " ";
        } else {
            cout << dist[i] << " ";
        }
    }
    cout << endl;

    return 0;
}
