#include <iostream>

using namespace std;

const int INF = 1000000000;

struct Edge {
    int to, weight;
};

void dijkstra(int N, const Edge* graph[], int* dist) {
    bool* visited = new bool[N + 1];
    for (int i = 1; i <= N; ++i) {
        visited[i] = false;
    }

    dist[1] = 0;
    for (int i = 1; i <= N; ++i) {

        int u = -1;
        for (int v = 1; v <= N; ++v) {
            if (!visited[v] && (u == -1 || dist[v] < dist[u])) {
                u = v;
            }
        }

        if (dist[u] == INF) break;

        visited[u] = true;


        for (int j = 0; graph[u][j].to != -1; ++j) {
            int v = graph[u][j].to;
            int weight = graph[u][j].weight;
            if (dist[u] + weight < dist[v]) {
                dist[v] = dist[u] + weight;
            }
        }
    }

    delete[] visited;
}

int main() {
    int N, M;
    cin >> N >> M;

    Edge** graph = new Edge*[N + 1];
    for (int i = 0; i <= N; ++i) {
        graph[i] = new Edge[N + 1];
        for (int j = 0; j <= N; ++j) {
            graph[i][j].to = -1;
        }
    }


    for (int i = 0; i < M; ++i) {
        int u, l, r;
        cin >> u >> l >> r;


        for (int v = l; v <= r; ++v) {
            int weight = v - l + 1;
            int idx = 0;

            while (graph[u][idx].to != -1) {
                ++idx;
            }
            graph[u][idx].to = v;
            graph[u][idx].weight = weight;
        }
    }


    int* dist = new int[N + 1];
    for (int i = 1; i <= N; ++i) {
        dist[i] = INF;
    }


    dijkstra(N, const_cast<const Edge**>(graph), dist);

    for (int i = 1; i <= N; ++i) {
        if (dist[i] == INF) {
            cout << -1 << " ";
        } else {
            cout << dist[i] << " ";
        }
    }
    cout << endl;

    for (int i = 0; i <= N; ++i) {
        delete[] graph[i];
    }
    delete[] graph;
    delete[] dist;

    return 0;
}
