#include <iostream>
#include <vector>
#include <queue>
#include <climits>

using namespace std;

struct RangeEdge {
    int l, r;
};

void dijkstra(int N, const vector<vector<RangeEdge>>& graph, vector<int>& dist) {
    priority_queue<pair<int, int>, vector<pair<int, int>>, greater<pair<int, int>>> pq;

    dist[1] = 0;
    pq.push({0, 1});

    while (!pq.empty()) {
        int u = pq.top().second;
        int current_dist = pq.top().first;
        pq.pop();


        if (current_dist > dist[u]) continue;

        for (const RangeEdge& e : graph[u]) {
            int l = e.l;
            int r = e.r;


            for (int v = l; v <= r; ++v) {
                int new_dist = dist[u] + (v - l + 1);

                if (new_dist < dist[v]) {
                    dist[v] = new_dist;
                    pq.push({dist[v], v});
                }
            }
        }
    }
}

int main() {
    int N, M;
    cin >> N >> M;

    vector<vector<RangeEdge>> graph(N + 1);

    for (int i = 0; i < M; ++i) {
        int u, l, r;
        cin >> u >> l >> r;

        graph[u].push_back({l, r});
    }

    vector<int> dist(N + 1, INT_MAX);

    dijkstra(N, graph, dist);

    for (int i = 1; i <= N; ++i) {
        if (dist[i] == INT_MAX) {
            cout << -1 << " ";
        } else {
            cout << dist[i] << " ";
        }
    }
    cout << endl;

    return 0;
}
