#include <iostream>
#include <vector>
#include <queue>
#include <limits>

using namespace std;

const int INF = numeric_limits<int>::max();
struct Edge {int to, weight; };

void dijkstra(int N, vector<vector<Edge>>& graph) 
{
    vector<int> dist(N + 1, INF);
    priority_queue<pair<int, int>, vector<pair<int, int>>, greater<>> pq;

    dist[1] = 0;
    pq.push({0, 1});

    while (!pq.empty()) 
    {
        auto [cur_dist, u] = pq.top();
        pq.pop();
        if (cur_dist > dist[u]) continue;
        for (const auto& edge : graph[u]) 
        {
            int v = edge.to;
            int weight = edge.weight;
            if (dist[u] + weight < dist[v]) 
            {
                dist[v] = dist[u] + weight;
                pq.push({dist[v], v});
            }
        }
    }

    for (int i = 1; i <= N; ++i) cout << (dist[i] == INF ? -1 : dist[i]) << " ";
    cout << endl;
}

int main() 
{
    int N, M;
    cin >> N >> M;
    vector<vector<Edge>> graph(N + 1);

    for (int i = 0; i < M; ++i) 
    {
        int u, l, r;
        cin >> u >> l >> r;
        for (int v = l; v <= r; ++v) graph[u].push_back({v, v - l + 1});
    }
    dijkstra(N, graph);
    return 0;
}
