#include <iostream>
#include <set>
#include <map>
using namespace std;
const long long MAXN = 5 * 1e5 + 1;
const long long INF = 1e15 + 1;
long long dist[MAXN];

set<long long> unvisited;

struct Ver{
    long long val;
    long long ind;
    pair<long long, long long> lazy;
};
Ver tree[8 * MAXN];

void build(long long curr, long long from, long long to) {
    if (from == to) {
        tree[curr].val = INF;
        dist[curr] = INF;
        tree[curr].ind = from;
        tree[curr].lazy = {0, 2 * INF};
        if (from == 1) {
            tree[curr].val = 0;
            dist[curr] = 0;
        }
    } else {
        build(curr * 2, from, (from + to) / 2);
        build(curr * 2 + 1, (from + to) / 2 + 1, to);
        if (tree[curr * 2].val <= tree[curr * 2 + 1].val) {
            tree[curr].val = tree[curr * 2].val;
            tree[curr].ind = tree[curr * 2].ind;
        } else {
            tree[curr].val = tree[curr * 2 + 1].val;
            tree[curr].ind = tree[curr * 2 + 1].ind;
        }
        tree[curr].lazy = {0, 2 * INF};
    }
}
inline void push(long long curr, long long from, long long to) {
//    if (tree[curr].lazy.first == 0 || tree[curr].val == INF + 1) {
//        return;
//    }
    set<long long>::iterator it = unvisited.lower_bound(from);

    if (tree[curr].val > tree[curr].lazy.first + tree[curr].lazy.second + *it - from) {
        tree[curr].val = tree[curr].lazy.first + tree[curr].lazy.second + *it - from;
        tree[curr].ind = *it;
    }
//    cout << "push: " << from << ' ' << to << " - " << tree[curr].val << '\n';

    if (tree[curr * 2].lazy.first == 0 || tree[curr * 2].lazy.first + tree[curr * 2].lazy.second > tree[curr].lazy.first + tree[curr].lazy.second) {
        tree[curr * 2].lazy = tree[curr].lazy;
    }
    if (tree[curr * 2 + 1].lazy.first == 0 || tree[curr * 2 + 1].lazy.first + tree[curr * 2 + 1].lazy.second > tree[curr].lazy.first + (from + to) / 2 + 1 - from + tree[curr].lazy.second) {
        tree[curr * 2 + 1].lazy = {tree[curr].lazy.first + (from + to) / 2 + 1 - from, tree[curr].lazy.second};
    }
    tree[curr].lazy = {0, 2 * INF};
}
void update(long long curr, long long from, long long to, long long l, long long r, pair<long long, long long> laz) {
    if (tree[curr].lazy.first != 0) {
        push(curr, from, to);
    }
    if (l <= from && to <= r) {
        tree[curr].lazy = {from - l + 1, laz.second};
//        cout << "lazy: " << from << ' ' << to << " - " << from - l + 1 << ' ' << laz.second << '\n';
        push(curr, from, to);
    } else if (l <= to && from <= r) {
        update(curr * 2, from, (from + to) / 2, l, r, laz);
        update(curr * 2 + 1, (from + to) / 2 + 1, to, l, r, laz);
        if (tree[curr * 2].val <= tree[curr * 2 + 1].val) {
            tree[curr].val = tree[curr * 2].val;
            tree[curr].ind = tree[curr * 2].ind;
        } else {
            tree[curr].val = tree[curr * 2 + 1].val;
            tree[curr].ind = tree[curr * 2 + 1].ind;
        }
    }
}
void degrade(long long curr, long long from, long long to, long long target) {
    if (tree[curr].lazy.first != 0) {
        push(curr, from, to);
    }
    if (from <= target && target <= to) {
        if (from == to) {
            dist[target] = tree[curr].val;
            tree[curr].val = INF + 1;
        } else {
            degrade(curr * 2, from, (from + to) / 2, target);
            degrade(curr * 2 + 1, (from + to) / 2 + 1, to, target);
            if (tree[curr * 2].val <= tree[curr * 2 + 1].val) {
                tree[curr].val = tree[curr * 2].val;
                tree[curr].ind = tree[curr * 2].ind;
            } else {
                tree[curr].val = tree[curr * 2 + 1].val;
                tree[curr].ind = tree[curr * 2 + 1].ind;
            }
//            cout << "grading: " << from << ' ' << to << " - " << tree[curr].val << ' ' << tree[curr].ind << '\n';
        }
    }
}
pair<long long, long long> query(long long curr, long long from, long long to, long long l, long long r) {
    if (tree[curr].lazy.first != 0) {
        push(curr, from, to);
    }
    if (l <= from && to <= r) {
        return {tree[curr].val, tree[curr].ind};
    } else if (l <= to && from <= r) {
        auto a = query(curr * 2, from, (from + to) / 2, l, r);
        auto b = query(curr * 2 + 1, (from + to) / 2 + 1, to, l, r);
        if (a.first <= b.first) {
            return a;
        } else {
            return b;
        }
    }
    return {INF + 1, -1};
}
int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(0);
    cout.tie(0);

    long long n, m;
    cin >> n >> m;
    multimap< long long, pair<long long, long long> > segs;
    for (long long i = 1; i <= m; i++) {
        long long u, l, r;
        cin >> u >> l >> r;
        segs.insert({u, {l, r}});
    }
    for (long long i = 1; i <= n; i++) {
        unvisited.insert(i);
    }
    build(1, 1, n);

//    cout << "min: " << tree[1].ind << ' ' << tree[1].val << '\n';

    for (long long i = 1; i <= n; i++) {
//        auto v = query(1, 1, n, 1, n);
        if (tree[1].lazy.first != 0) {
            push(1, 1, n);
        }
        pair<long long, long long> v = {tree[1].val, tree[1].ind};
//        cout << v.second << ' ' << v.first << ":\n";
        if (v.first < INF) {
            multimap< long long, pair<long long, long long> >::iterator it = segs.lower_bound(v.second);
            if (it == segs.end()) {
                continue;
            }
            while ((*it).first == v.second) {
                update(1, 1, n, (*it).second.first, (*it).second.second, {1, v.first});

                if (tree[1].lazy.first != 0) {
                    push(1, 1, n);
                }
//                cout << "min: " << tree[1].ind << ' ' << tree[1].val << '\n';
                it++;
                if (it == segs.end()) {
                    break;
                }
            }
        }
        degrade(1, 1, n, v.second);
        unvisited.erase(v.second);
    }
    for (long long i = 1; i <= n; i++) {
        if (dist[i] >= INF) {
            cout << -1 << ' ';
        } else {
            cout << dist[i] << ' ';
        }
    }
    return 0;
}
